@@ -1,8 +1,5 @@
 DATA_DIR = "/usr/local/share"
 LIB_DIR = "/usr/local/lib"
-VERSION = "2.24.3"
+VERSION = "2.28.2"
 PACKAGE = "hamster-applet"
 PYTHONDIR = "/usr/local/lib/python2.5/site-packages"
-
-import sys, os.path 
-sys.path.append(".libs") 
\ No newline at end of file
